/* files.h   File inputs Declarations */

#define CALIB_DIR "calib-inputs/" /*source of calibration inputs & routines*/

char *mygetline(char *,int, FILE *); /*ignoring comments & blanks*/

#define MYGETLINE(b, s, f, mess, rv) \
    {if (mygetline(b, s, f) == NULL) {fprintf(stderr, mess); return rv;}}



